==> maradns_0.9.15.orig.tar.gz: maradns-0.9.15/server/MaraDNS_en.h <==
#define L_LOG "Log: "
#define L_N "\n"
#define L_FATAL "Fatal error: "
#define L_ACL_LIST_RECURSE "Could not make ip ACL list for recursive queries"
#define L_INIT_SPAMMERS "Could not make spammers list"
#define L_RANDOM_IF_RECURSE "random_seed_file must be set if recursive DNS is enabled"
#define L_INVALID_CACHESIZE "maximum_cache_size has invalid value.  Reverting to default value."
#define L_BIND2ADDR "Binding to address "
#define L_CAUGHT_PIPE "Caught SIGPIPE"
#define L_CAUGHT_SIG "Caught Signal"
#define L_BAD_QUERY "Bad query received: "
#define L_SYSERROR "System said"
#define L_MLC "Could not create mararc_loc string"
#define L_MLL "Could not set locale for mararc_loc string"
#define L_EC "Could not create errors string"
#define L_EL "Could not set locale for errors string"
#define L_UC "Could not create uidstr string"
#define L_UL "Could not set locale for uidstr string"
#define L_VC "Could not create verbstr string"
#define L_VL "Could not set locale for verbstr string"
#define L_MC "Could not create maxpstr string"
#define L_ML "Could not set locale for maxpstr string"
#define L_CC "Could not create chrootn string"
#define L_CL "Could not set locale for chrootn string"
#define L_KQC "Could not create kvar_query string"
#define L_KQL "Could not set locale for kvar_query string"
#define L_BAC "Could not create bins_address string"
#define L_BAL "Could not set locale for bind_address string"
#define L_IC "Could not create incoming string"
#define L_IL "Could not set locale for incoming string"
#define L_UCC "Could not create uncomp string"
#define L_UCL "Could not set locale for uncomp string"
#define L_LOC_MARARC "Error locating mararc file"
#define L_MARARC_ARG "Could not get mararc from command line"
#define L_USAGE "Usage: mararc [-f mararc_location]"
#define L_MARARC_PARSE "Error parsing contents of mararc file"
#define L_MARARC_LINE "Error parsing contents of mararc file on line "
#define L_ERROR_CODE "Error code: "
#define L_KVAR_Q "Could not create kvar_query"
#define L_MAXPROC "Problem getting maxprocs value.\nmaxprocs must be set before starting the MaraDNS server"
#define L_MAXPROC_NUM "Problem converting maxprocs to a number\nThis must be a non-zero number"
#define L_MAXPROC_SET "Unable to set maximum number of processes"
#define L_MAXPROC_MAX "maxprocs can not be greater than 200\nSetting maxprocs to 200"
#define L_CHROOT_KVAR "Problem getting chroot kvar.\nYou must have chroot_dir set if you start this as root"
#define L_CHROOT_NT "Problem making chroot nt string.\nMake sure the chroot directory is 200 chars or less"
#define L_CHROOT_CHANGE "Problem changing to chroot dir.\nMake sure chroot_dir points to a valid directory"
#define L_CHROOT_DO "Problem changing the root directory."
#define L_CHROOT_SUCCESS "Root directory changed"
#define L_NOBIND "Problem getting chroot kvar.\nYou must have bind_address set to the IP maradns will listen on"
#define L_BINDFAIL "Problem binding to port 53.\nMost likely, another process is already listening on port 53"
#define L_BIND_SUCCESS "Socket opened on UDP port 53"
#define L_NOUID "Problem getting maradns_uid kvar.\nYou must have maradns_uid set if you start this as root"
#define L_BADUID "maradns_uid is less than 10 or not a number.\nThis uid must have a value of 10 or more"
#define L_NODROP "Could not drop root uid"
#define L_STILL_ROOT "We seem to still be root"
#define L_DROP_SUCCESS "Root privledges dropped"
#define L_BEROOT "Problem binding to port 53.\nYou should run this as root"
#define L_NOBIGHASH "Could not create big hash"
#define L_NOPOPULATE "Error running populate_main program.  Please read the MaraDNS FAQ"
#define L_POPULATE_FATAL "This error in populate hash is fatal"
#define L_RRS_LOADED "All RRs have been loaded"
#define L_DATAWAIT "Awaiting data on port 53"
#define L_GOTDATA "Message received, processing"
#define L_INITCACHE_FAIL "Init_cache() failed.  If you are seeing this, it is a bug.\nPlease read the MaraDNS FAQ"
#define L_ERROR_VALUE "Error value (for software devlopers): "
#define L_INITCRYPTO_FAIL "Init_crypto() failed.  If you are seeing this, it is a bug.\nPlease read the MaraDNS FAQ"
#define L_OPENSEED_FAIL "Could not open the random_seed_file"
#define L_NEED16BYTES "The random_seed_file needs to be 16 bytes or longer"
#define L_SORRY_SOLARIS "OK, since you are using Solaris, which means the recursive stuff leaks\nmemory.  Which means that I have to disable recursion on Solaris until I can\nget access to a Solaris box to fix this !@#$ bug.  Patches which fix this\nproblem are welcome, but until then, disable recursion in the mararc file\nto run MaraDNS"
#define L_THISIS "This is MaraDNS version"
#define L_COMPILED "Compiled on a"
#define L_RTFM "For usage information, 'man maradns'"
#define L_SETROOTNS "root_servers[\".\"] must be set in the mararc file\ne.g. root_servers[\".\"] = \"198.41.0.4\"\nIn addition, root_servers = {} must preceed this line"
#define L_BADROOTNS "root_servers[\".\"] in the mararc file is invalid.\nExample good value: root_servers[\".\"] = \"198.41.0.4\""
#define L_INVALID_MAXGLUE "max_glueless_level needs to be a number, and be greater than zero"
#define L_INVALID_MAXQTOTAL "max_queries_total needs to be a number, and be greater than zero"
#define L_INVALID_TIMEOUT "timeout_seconds needs to be a number, and be greater than zero"

==> maradns_1.0.27.orig.tar.gz: maradns-1.0.27/server/MaraDNS_en.h <==
#define L_LOG " Log: "
#define L_N "\n"
#define L_FATAL "Fatal error: "
#define L_ACL_LIST_RECURSE "Could not make ip ACL list for recursive queries"
#define L_INIT_SPAMMERS "Could not make spammers list"
#define L_RANDOM_IF_RECURSE "random_seed_file must be set if recursive DNS is enabled"
#define L_INVALID_CACHESIZE "maximum_cache_size has invalid value.  Reverting to default value."
#define L_BIND2ADDR "Binding to address "
#define L_CAUGHT_PIPE "Caught SIGPIPE"
#define L_CAUGHT_SIG "Caught Signal"
#define L_BAD_QUERY "Bad query received: "
#define L_SYSERROR "System said"
#define L_MLC "Could not create mararc_loc string"
#define L_MLL "Could not set locale for mararc_loc string"
#define L_EC "Could not create errors string"
#define L_EL "Could not set locale for errors string"
#define L_UC "Could not create uidstr string"
#define L_UL "Could not set locale for uidstr string"
#define L_VC "Could not create verbstr string"
#define L_VL "Could not set locale for verbstr string"
#define L_MC "Could not create maxpstr string"
#define L_ML "Could not set locale for maxpstr string"
#define L_CC "Could not create chrootn string"
#define L_CL "Could not set locale for chrootn string"
#define L_KQC "Could not create kvar_query string"
#define L_KQL "Could not set locale for kvar_query string"
#define L_BAC "Could not create bins_address string"
#define L_BAL "Could not set locale for bind_address string"
#define L_IC "Could not create incoming string"
#define L_IL "Could not set locale for incoming string"
#define L_UCC "Could not create uncomp string"
#define L_UCL "Could not set locale for uncomp string"
#define L_LOC_MARARC "Error locating mararc file"
#define L_MARARC_ARG "Could not get mararc from command line"
#define L_USAGE "Usage: mararc [-f mararc_location]"
#define L_MARARC_PARSE "Error parsing contents of mararc file"
#define L_MARARC_LINE "Error parsing contents of mararc file on line "
#define L_ERROR_CODE "Error code: "
#define L_KVAR_Q "Could not create kvar_query"
#define L_MAXPROC "Problem getting maxprocs value.\nmaxprocs must be set before starting the MaraDNS server"
#define L_MAXPROC_NUM "Problem converting maxprocs to a number\nThis must be a non-zero number"
#define L_MAXPROC_SET "Unable to set maximum number of processes"
#define L_MAXPROC_MAX "maxprocs can not be greater than 500\nSetting maxprocs to 500"
#define L_CHROOT_KVAR "Problem getting chroot kvar.\nYou must have chroot_dir set if you start this as root"
#define L_CHROOT_NT "Problem making chroot nt string.\nMake sure the chroot directory is 200 chars or less"
#define L_CHROOT_CHANGE "Problem changing to chroot dir.\nMake sure chroot_dir points to a valid directory"
#define L_CHROOT_DO "Problem changing the root directory."
#define L_CHROOT_SUCCESS "Root directory changed"
#define L_NOBIND "Problem getting chroot kvar.\nYou must have bind_address set to the IP maradns will listen on"
#define L_BINDFAIL "Problem binding to port 53.\nMost likely, another process is already listening on port 53"
#define L_BIND_SUCCESS "Socket opened on UDP port 53"
#define L_NOUID "Problem getting maradns_uid kvar.\nYou must have maradns_uid set if you start this as root"
#define L_BADUID "maradns_uid is less than 10 or not a number.\nThis uid must have a value of 10 or more"
#define L_NODROP "Could not drop root uid"
#define L_STILL_ROOT "We seem to still be root"
#define L_DROP_SUCCESS "Root privledges dropped"
#define L_BEROOT "Problem binding to port 53.\nYou should run this as root"
#define L_NOBIGHASH "Could not create big hash"
#define L_NOPOPULATE "Error running populate_main program.  Please read the MaraDNS FAQ"
#define L_POPULATE_FATAL "This error in populate hash is fatal"
#define L_RRS_LOADED "All RRs have been loaded"
#define L_DATAWAIT "Awaiting data on port 53"
#define L_GOTDATA "Message received, processing"
#define L_INITCACHE_FAIL "Init_cache() failed.  If you are seeing this, it is a bug.\nPlease read the MaraDNS FAQ"
#define L_ERROR_VALUE "Error value (for software devlopers): "
#define L_INITCRYPTO_FAIL "Init_crypto() failed.  If you are seeing this, it is a bug.\nPlease read the MaraDNS FAQ"
#define L_OPENSEED_FAIL "Could not open the random_seed_file"
#define L_NEED16BYTES "The random_seed_file needs to be 16 bytes or longer"
#define L_THISIS "This is MaraDNS version"
#define L_COMPILED "Compiled on a"
#define L_RTFM "For usage information, 'man maradns'"
#define L_SETROOTNS "root_servers[\".\"] or upstream_servers[\".\"] must be set in the\nmararc file\ne.g. root_servers[\".\"] = \"198.41.0.4\"\nIn addition, root_servers = {} (or upstream_servers = {}) must preceed this\nline"
#define L_BADROOTNS "root_servers[\".\"] (or upstream_servers) in the mararc file\nis invalid.\nExample good value: root_servers[\".\"] = \"198.41.0.4\""
#define L_CHOOSEONE "Both root_servers and upstream_servers are set in the mararc file\nPlease chosse one or the other; both can not be active at the same time."
#define L_INVALID_MAXGLUE "max_glueless_level needs to be a number, and be greater than zero"
#define L_INVALID_MAXQTOTAL "max_queries_total needs to be a number, and be greater than zero"
#define L_INVALID_TIMEOUT "timeout_seconds needs to be a number, and be greater than zero"
#define L_TIMESTAMP "Timestamp: "
#define L_COMPRESS_ERROR "Compression error: "
